<template>
  <el-dialog
    width="50%"
    title="损失登记"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <div>
      <el-table :data="lossData" style="width: 100%">
        <el-table-column
          prop="lotBatchNo"
          label="零件批号"
          width="150"
          align="center"
        >
        </el-table-column>
        <el-table-column
          prop="partNo"
          label="零件编号"
          width="150"
          align="center"
        >
        </el-table-column>
        <el-table-column
          prop="partDesc"
          label="零件名称"
          align="center"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          prop="unqualifiedArrived"
          label="不合格数量"
          width="80"
          align="center"
        >
        </el-table-column>
        <el-table-column
          prop="qualityLoss"
          label="质量损失"
          align="center"
          width="130"
        >
          <template slot-scope="scope">
            <el-input
              v-model="scope.row.qualityLoss"
              placeholder="质量损失"
              clearable
            ></el-input>
          </template>
        </el-table-column>
      </el-table>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >登 记</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { updateBatch } from '@/api/quality/unqualifiedprocess'
import { validateSixDecimalPositive } from '../../../util/validate'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    registerLossList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      lossData: []
    }
  },

  methods: {
    checkZero(value) {
      if (value == 0) {
        return false
      } else {
        return true
      }
    },
    checkPositive(value) {
      if (!/^[0-9]+.?[0-9]*$/.test(value)) {
        return false
      } else {
        return true
      }
    },
    checkDecimal(value) {
      if (
        !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
          value
        )
      ) {
        return false
      } else {
        return true
      }
    },
    saveSelectRow() {
      this.isSubmit = true
      const formDataList = []
      let formData
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.lossData.length; i++) {
        if (
          this.lossData[i].qualityLoss == null ||
          this.lossData[i].qualityLoss == ''
        ) {
          flag = false
          flagMsg = flagMsg + '第' + (i + 1) + '行，质量损失不能为空；'
        } else {
          if (!this.checkZero(this.lossData[i].qualityLoss)) {
            flag = false
            flagMsg = flagMsg + '第' + (i + 1) + '行，质量损失不能为0；'
          } else {
            if (!this.checkPositive(this.lossData[i].qualityLoss)) {
              flag = false
              flagMsg = flagMsg + '第' + (i + 1) + '行，质量损失需为正数；'
            } else {
              if (!this.checkDecimal(this.lossData[i].qualityLoss)) {
                flag = false
                flagMsg =
                  flagMsg + '第' + (i + 1) + '行，质量损失最多六位小数；'
              } else {
                formData = {
                  id: this.lossData[i].id,
                  lossRegistration: this.lossData[i].qualityLoss
                }
                formDataList.push(formData)
              }
            }
          }
        }
      }
      if (flag) {
        updateBatch(formDataList)
          .then((response) => {
            const resData = response.data
            if (resData.code === 0) {
              this.innerVisible = false
              this.$message.success('损失登记成功')
              this.$emit('refreshDataList')
            } else {
              this.$message.error('损失登记失败')
            }
            this.isSubmit = false
          })
          .catch(() => {
            this.isSubmit = false
          })
      } else {
        this.$message.error(flagMsg)
        this.isSubmit = false
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          let loss
          this.lossData = []
          this.registerLossList.forEach((item) => {
            loss = {
              id: item.id,
              lotBatchNo: item.lotBatchNo,
              partNo: item.partNo,
              partDesc: item.partDesc,
              unqualifiedArrived: item.unqualifiedArrived,
              qualityLoss: item.qualityLoss
            }
            this.lossData.push(loss)
          })
        })
      }
    }
  }
}
</script>
